@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::PreviousVersion::Changelog::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: extract previous version from changelog
-$Dist::Zilla::Plugin::PreviousVersion::Changelog::VERSION = '0.2.1';
+$Dist::Zilla::Plugin::PreviousVersion::Changelog::VERSION = '0.2.2';
 
 use strict;
 use warnings;
@@ -26,15 +26,15 @@ has changelog => (
     lazy => 1,
     default => sub {
         my $self = shift;
-        my $changes_file = first { $_->name eq $self->filename } 
+        my $changes_file = first { $_->name eq $self->filename }
                                  @{ $self->zilla->files }
-            or $self->log_fatal( 
-                    "changelog '@{[ $self->filename ]}' not found" ); 
+            or $self->log_fatal(
+                    "changelog '@{[ $self->filename ]}' not found" );
 
-        CPAN::Changes->load_string( 
-            $changes_file->content, 
-            next_token => qr/{{\$NEXT}}/ 
-        ); 
+        CPAN::Changes->load_string(
+            $changes_file->content,
+            next_token => qr/{{\$NEXT}}/
+        );
     },
 );
 
@@ -42,12 +42,9 @@ sub provide_previous_version {
     my $self = shift;
 
     # TODO {{$NEXT}} not generic enough
-    my $version = 
-           first { $_ ne '{{$NEXT}}' } 
+    return first { $_ ne '{{$NEXT}}' } 
            map   { $_->version }
            reverse $self->changelog->releases;
-
-    return $version || '0.0.0';
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -66,7 +63,7 @@ Dist::Zilla::Plugin::PreviousVersion::Changelog - extract previous version from
 
 =head1 VERSION
 
-version 0.2.1
+version 0.2.2
 
 =head1 DESCRIPTION
 
